==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/compute_service_attachment/ComputeServiceAttachmentConsumerAcceptLists.java <==
package com.hashicorp.cdktf.providers.google.compute_service_attachment;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:40.013Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.computeServiceAttachment.ComputeServiceAttachmentConsumerAcceptLists")
@software.amazon.jsii.Jsii.Proxy(ComputeServiceAttachmentConsumerAcceptLists.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ComputeServiceAttachmentConsumerAcceptLists extends software.amazon.jsii.JsiiSerializable {

    /**
     * The number of consumer forwarding rules the consumer project can create.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/compute_service_attachment#connection_limit ComputeServiceAttachment#connection_limit}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getConnectionLimit();

    /**
     * A project that is allowed to connect to this service attachment.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/compute_service_attachment#project_id_or_num ComputeServiceAttachment#project_id_or_num}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getProjectIdOrNum();

    /**
     * @return a {@link Builder} of {@link ComputeServiceAttachmentConsumerAcceptLists}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ComputeServiceAttachmentConsumerAcceptLists}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ComputeServiceAttachmentConsumerAcceptLists> {
        java.lang.Number connectionLimit;
        java.lang.String projectIdOrNum;

        /**
         * Sets the value of {@link ComputeServiceAttachmentConsumerAcceptLists#getConnectionLimit}
         * @param connectionLimit The number of consumer forwarding rules the consumer project can create. This parameter is required.
         *                        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/compute_service_attachment#connection_limit ComputeServiceAttachment#connection_limit}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder connectionLimit(java.lang.Number connectionLimit) {
            this.connectionLimit = connectionLimit;
            return this;
        }

        /**
         * Sets the value of {@link ComputeServiceAttachmentConsumerAcceptLists#getProjectIdOrNum}
         * @param projectIdOrNum A project that is allowed to connect to this service attachment. This parameter is required.
         *                       Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/compute_service_attachment#project_id_or_num ComputeServiceAttachment#project_id_or_num}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder projectIdOrNum(java.lang.String projectIdOrNum) {
            this.projectIdOrNum = projectIdOrNum;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ComputeServiceAttachmentConsumerAcceptLists}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ComputeServiceAttachmentConsumerAcceptLists build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ComputeServiceAttachmentConsumerAcceptLists}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ComputeServiceAttachmentConsumerAcceptLists {
        private final java.lang.Number connectionLimit;
        private final java.lang.String projectIdOrNum;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.connectionLimit = software.amazon.jsii.Kernel.get(this, "connectionLimit", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.projectIdOrNum = software.amazon.jsii.Kernel.get(this, "projectIdOrNum", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.connectionLimit = java.util.Objects.requireNonNull(builder.connectionLimit, "connectionLimit is required");
            this.projectIdOrNum = java.util.Objects.requireNonNull(builder.projectIdOrNum, "projectIdOrNum is required");
        }

        @Override
        public final java.lang.Number getConnectionLimit() {
            return this.connectionLimit;
        }

        @Override
        public final java.lang.String getProjectIdOrNum() {
            return this.projectIdOrNum;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("connectionLimit", om.valueToTree(this.getConnectionLimit()));
            data.set("projectIdOrNum", om.valueToTree(this.getProjectIdOrNum()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.computeServiceAttachment.ComputeServiceAttachmentConsumerAcceptLists"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ComputeServiceAttachmentConsumerAcceptLists.Jsii$Proxy that = (ComputeServiceAttachmentConsumerAcceptLists.Jsii$Proxy) o;

            if (!connectionLimit.equals(that.connectionLimit)) return false;
            return this.projectIdOrNum.equals(that.projectIdOrNum);
        }

        @Override
        public final int hashCode() {
            int result = this.connectionLimit.hashCode();
            result = 31 * result + (this.projectIdOrNum.hashCode());
            return result;
        }
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/compute_service_attachment/ComputeServiceAttachmentConsumerAcceptLists.java <==
package com.hashicorp.cdktf.providers.google.compute_service_attachment;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:13.950Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.computeServiceAttachment.ComputeServiceAttachmentConsumerAcceptLists")
@software.amazon.jsii.Jsii.Proxy(ComputeServiceAttachmentConsumerAcceptLists.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ComputeServiceAttachmentConsumerAcceptLists extends software.amazon.jsii.JsiiSerializable {

    /**
     * The number of consumer forwarding rules the consumer project can create.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/compute_service_attachment#connection_limit ComputeServiceAttachment#connection_limit}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getConnectionLimit();

    /**
     * The network that is allowed to connect to this service attachment. Only one of project_id_or_num and network_url may be set.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/compute_service_attachment#network_url ComputeServiceAttachment#network_url}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getNetworkUrl() {
        return null;
    }

    /**
     * A project that is allowed to connect to this service attachment. Only one of project_id_or_num and network_url may be set.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/compute_service_attachment#project_id_or_num ComputeServiceAttachment#project_id_or_num}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getProjectIdOrNum() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ComputeServiceAttachmentConsumerAcceptLists}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ComputeServiceAttachmentConsumerAcceptLists}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ComputeServiceAttachmentConsumerAcceptLists> {
        java.lang.Number connectionLimit;
        java.lang.String networkUrl;
        java.lang.String projectIdOrNum;

        /**
         * Sets the value of {@link ComputeServiceAttachmentConsumerAcceptLists#getConnectionLimit}
         * @param connectionLimit The number of consumer forwarding rules the consumer project can create. This parameter is required.
         *                        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/compute_service_attachment#connection_limit ComputeServiceAttachment#connection_limit}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder connectionLimit(java.lang.Number connectionLimit) {
            this.connectionLimit = connectionLimit;
            return this;
        }

        /**
         * Sets the value of {@link ComputeServiceAttachmentConsumerAcceptLists#getNetworkUrl}
         * @param networkUrl The network that is allowed to connect to this service attachment. Only one of project_id_or_num and network_url may be set.
         *                   Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/compute_service_attachment#network_url ComputeServiceAttachment#network_url}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder networkUrl(java.lang.String networkUrl) {
            this.networkUrl = networkUrl;
            return this;
        }

        /**
         * Sets the value of {@link ComputeServiceAttachmentConsumerAcceptLists#getProjectIdOrNum}
         * @param projectIdOrNum A project that is allowed to connect to this service attachment. Only one of project_id_or_num and network_url may be set.
         *                       Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/compute_service_attachment#project_id_or_num ComputeServiceAttachment#project_id_or_num}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder projectIdOrNum(java.lang.String projectIdOrNum) {
            this.projectIdOrNum = projectIdOrNum;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ComputeServiceAttachmentConsumerAcceptLists}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ComputeServiceAttachmentConsumerAcceptLists build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ComputeServiceAttachmentConsumerAcceptLists}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ComputeServiceAttachmentConsumerAcceptLists {
        private final java.lang.Number connectionLimit;
        private final java.lang.String networkUrl;
        private final java.lang.String projectIdOrNum;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.connectionLimit = software.amazon.jsii.Kernel.get(this, "connectionLimit", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.networkUrl = software.amazon.jsii.Kernel.get(this, "networkUrl", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.projectIdOrNum = software.amazon.jsii.Kernel.get(this, "projectIdOrNum", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.connectionLimit = java.util.Objects.requireNonNull(builder.connectionLimit, "connectionLimit is required");
            this.networkUrl = builder.networkUrl;
            this.projectIdOrNum = builder.projectIdOrNum;
        }

        @Override
        public final java.lang.Number getConnectionLimit() {
            return this.connectionLimit;
        }

        @Override
        public final java.lang.String getNetworkUrl() {
            return this.networkUrl;
        }

        @Override
        public final java.lang.String getProjectIdOrNum() {
            return this.projectIdOrNum;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("connectionLimit", om.valueToTree(this.getConnectionLimit()));
            if (this.getNetworkUrl() != null) {
                data.set("networkUrl", om.valueToTree(this.getNetworkUrl()));
            }
            if (this.getProjectIdOrNum() != null) {
                data.set("projectIdOrNum", om.valueToTree(this.getProjectIdOrNum()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.computeServiceAttachment.ComputeServiceAttachmentConsumerAcceptLists"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ComputeServiceAttachmentConsumerAcceptLists.Jsii$Proxy that = (ComputeServiceAttachmentConsumerAcceptLists.Jsii$Proxy) o;

            if (!connectionLimit.equals(that.connectionLimit)) return false;
            if (this.networkUrl != null ? !this.networkUrl.equals(that.networkUrl) : that.networkUrl != null) return false;
            return this.projectIdOrNum != null ? this.projectIdOrNum.equals(that.projectIdOrNum) : that.projectIdOrNum == null;
        }

        @Override
        public final int hashCode() {
            int result = this.connectionLimit.hashCode();
            result = 31 * result + (this.networkUrl != null ? this.networkUrl.hashCode() : 0);
            result = 31 * result + (this.projectIdOrNum != null ? this.projectIdOrNum.hashCode() : 0);
            return result;
        }
    }
}
